@@ -9,6 +9,7 @@
 ## usethis namespace: end
 NULL
 
-utils::globalVariables(c("PredictedValue", "low", "predicted.value", "up",
-                         "x", "y", "z", "color_blind","xmin", "xmax", "ymin",
-                         "ymax", "Row", "treatments", "stdres", "groups"))
+utils::globalVariables(c("PredictedValue", "low", "predicted.value",
+                         "up", "x", "y", "z", "color_blind","xmin",
+                         "xmax", "ymin", "ymax", "Row", "treatments",
+                         "stdres", "groups", ".data"))
