@@ -1,8 +1,8 @@
 #' Produces a skeletal ANOVA table
 #'
-#' @param design.obj An `agricolae` design object.
+#' @param design.obj A modified `agricolae` design object as output from des_info.
 #'
-#' @return Prints skeletal ANOVA table to console output.
+#' @returns Prints skeletal ANOVA table to console output.
 #'
 #' @keywords internal
 #'
@@ -16,12 +16,12 @@ satab <- function(design.obj) {
 
   design.obj <- design.obj$book
 
-  if (design != "split") {
+  if(design != "split") {
     output <- paste0(format("Source of Variation", width = 40), "df", "\n")
     output <- c(output, paste0("=============================================\n"))
   }
 
-  if (design == "crd") {
+  if(design == "crd") {
     trt <- names(design.obj)[3]
     totdf <- nrow(design.obj) - 1
     trtdf <- length(unique(design.obj[, 3])) - 1
@@ -33,7 +33,7 @@ satab <- function(design.obj) {
     output <- c(output, paste0(format("Total", width = 40), totdf, "\n"))
   }
 
-  if (design == "rcbd") {
+  if(design == "rcbd") {
     trt <- names(design.obj)[3]
     blkdf <- length(unique(design.obj$block)) - 1
     totdf <- nrow(design.obj) - 1
@@ -48,7 +48,7 @@ satab <- function(design.obj) {
     output <- c(output, paste0(format("Total", width = 40), totdf, "\n"))
   }
 
-  if (design == "factorial_crd") {
+  if(design == "factorial_crd") {
     trt <- names(design.obj)[3:length(names(design.obj))]
     totdf <- nrow(design.obj) - 1
     trtdf <- c()
@@ -68,7 +68,7 @@ satab <- function(design.obj) {
   }
 
 
-  if (design == "factorial_rcbd") {
+  if(design == "factorial_rcbd") {
     trt <- names(design.obj)[3:length(names(design.obj))]
     totdf <- nrow(design.obj) - 1
     trtdf <- c()
@@ -90,7 +90,7 @@ satab <- function(design.obj) {
     output <- c(output, paste0(format("Total", width = 40), totdf, "\n"))
   }
 
-  if (design == "lsd") {
+  if(design == "lsd") {
     trt <- names(design.obj)[4]
     rowdf <- length(unique(design.obj$row)) - 1
     coldf <- length(unique(design.obj$col)) - 1
@@ -108,16 +108,16 @@ satab <- function(design.obj) {
 
 
 
-  if (design == "split") {
+  if(design == "split") {
     blkdf <- length(unique(design.obj$block)) - 1
     totdf <- nrow(design.obj) - 1
     numwplots <- nrow(design.obj) / length(unique(design.obj$splots))
-    sp.facWdf <- length(unique(design.obj[, 4])) - 1
-    wpresdf <- (numwplots - 1) - blkdf - sp.facWdf
 
-    trtAdf <- length(unique(design.obj[, 4])) - 1
-    trtBdf <- length(unique(design.obj[, 5])) - 1
+    trtAdf <- length(unique(design.obj[, 5])) - 1
+    trtBdf <- length(unique(design.obj[, 6])) - 1
     trtABdf <- trtAdf * trtBdf
+
+    wpresdf <- (numwplots - 1) - blkdf - trtAdf
     errdf <- totdf - trtAdf - trtBdf - trtABdf - blkdf - wpresdf
 
     output <- paste0(format("Source of Variation", width = 45), "df", "\n")
@@ -125,18 +125,18 @@ satab <- function(design.obj) {
     output <- c(output, paste0(format("Block stratum", width = ifelse(blkdf>10, 44, 45)), blkdf, "\n"))
     output <- c(output, paste0("--------------------------------------------------\n"))
     output <- c(output, paste0("Whole plot stratum", "\n"))
-    output <- c(output, paste0(format(" ", width = 9), format(names(design.obj)[4], width = ifelse(trtAdf>10, 35, 36)), trtAdf, "\n"))
+    output <- c(output, paste0(format(" ", width = 9), format(names(design.obj)[5], width = ifelse(trtAdf>10, 35, 36)), trtAdf, "\n"))
     output <- c(output, paste0(format("Whole plot Residual", width = 45), wpresdf, "\n"))
     output <- c(output, paste0("==================================================\n"))
     output <- c(output, paste0("Subplot stratum", "\n"))
-    output <- c(output, paste0(format(" ", width = 9), format(names(design.obj)[5], width = ifelse(trtBdf>10, 35, 36)), trtBdf, "\n"))
-    output <- c(output, paste0(format(" ", width = 9), format(paste(names(design.obj)[4], names(design.obj)[5], sep = ":"), width = ifelse(trtABdf>10, 35, 36)), trtABdf, "\n"))
+    output <- c(output, paste0(format(" ", width = 9), format(names(design.obj)[6], width = ifelse(trtBdf>10, 35, 36)), trtBdf, "\n"))
+    output <- c(output, paste0(format(" ", width = 9), format(paste(names(design.obj)[5], names(design.obj)[6], sep = ":"), width = ifelse(trtABdf>10, 35, 36)), trtABdf, "\n"))
     output <- c(output, paste0(format(" ", width = 9), format("Subplot Residual", width = 35), errdf, "\n"))
     output <- c(output, paste0("==================================================\n"))
     output <- c(output, paste0(format("Total", width = ifelse(totdf>10, 44, 45)), totdf, "\n"))
   }
 
-  if (design == "factorial_lsd") {
+  if(design == "factorial_lsd") {
     rowdf <- length(unique(design.obj$row)) - 1
     coldf <- length(unique(design.obj$col)) - 1
     totdf <- nrow(design.obj) - 1
